# eric7.MicroPython.WifiDialogs.WifiNetworksWindow

Module implementing a dialog showing the available WiFi networks.

### Global Attributes

None

### Classes

WifiNetworksWindow | Class implementing a dialog showing the available WiFi networks.

### Functions

None

## WifiNetworksWindow

Class implementing a dialog showing the available WiFi networks.

### Derived from

QWidget, Ui_WifiNetworksWindow

### Class Attributes

None

### Class Methods

None

### Methods

WifiNetworksWindow | Constructor
__resizeColumns | Private method to resize the columns of the result list.
__resort | Private method to resort the networks list.
closeEvent | Protected method to handle a window close event.
on_intervalSpinBox_valueChanged | Private slot handling a change of the periodic scan interval.
on_periodicCheckBox_toggled | Private slot handling the selection of a periodic scan.
scanNetworks | Public slot to ask the device for a network scan and display the result.

### Static Methods

None

#### WifiNetworksWindow (Constructor)

WifiNetworksWindow(device, parent=None)

Constructor

device (BaseDevice)
  reference to the connected device
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### WifiNetworksWindow.__resizeColumns

__resizeColumns()

Private method to resize the columns of the result list.

#### WifiNetworksWindow.__resort

__resort()

Private method to resort the networks list.

#### WifiNetworksWindow.closeEvent

closeEvent(evt)

Protected method to handle a window close event.

evt (QCloseEvent)
  reference to the close event

#### WifiNetworksWindow.on_intervalSpinBox_valueChanged

on_intervalSpinBox_valueChanged(interval)

Private slot handling a change of the periodic scan interval.

interval (int)
  periodic scan interval

#### WifiNetworksWindow.on_periodicCheckBox_toggled

on_periodicCheckBox_toggled(checked)

Private slot handling the selection of a periodic scan.

checked (bool)
  flag indicating a periodic scan

#### WifiNetworksWindow.scanNetworks

scanNetworks()

Public slot to ask the device for a network scan and display the result.

Up